@@ -70,7 +70,7 @@ void FileListWidget::actionRename()
 {
     QFileInfo file = fileSystemModel->fileInfo(this->selectedIndexes().first());
     QString newName = QInputDialog::getText(this, tr("Rename"), tr("New filename: "), QLineEdit::Normal, file.fileName());
-    if(newName != file.fileName() && !newName.isEmpty())
+    if(newName != file.fileName())
     {
         if(QFile::rename(file.absoluteFilePath(), file.absolutePath()+"/"+newName))
             return;
@@ -239,10 +239,6 @@ void FileListWidget::handleItemActivation(QModelIndex index)
   */
 void FileListWidget::setSelectMode(bool mode)
 {
-    if(mode)
-        this->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    else
-        this->setSelectionMode(QAbstractItemView::SingleSelection);
     select = mode;
 }
 
@@ -269,7 +265,7 @@ void FileListWidget::actionSendFiles()
 
     // Make dbuscall to send files
     QDBusInterface interface("com.nokia.bt_ui", "/com/nokia/bt_ui", "com.nokia.bt_ui",QDBusConnection::systemBus());
-    interface.call(QDBus::Block, "show_send_file_dlg", files);
+    QDBusMessage reply = interface.call(QDBus::Block, "show_send_file_dlg", files);
 
 #else
     QMessageBox::information(this,
